@@ -71,12 +71,19 @@ def main(argv: Optional[list] = None):
     Returns:
         Exit code (0 for success, non-zero for errors)
     """
+    # Disable telemetry by default (set early in case any imported modules check it)
+    import os
+    os.environ.setdefault('DISABLE_TELEMETRY', '1')
+    
     # Ensure directories are initialized on first run
     ensure_directories()
 
     # Initialize or update project registry
     _initialize_project_registry()
 
+    # Verify MCP Gateway configuration on startup (non-blocking)
+    _verify_mcp_gateway_startup()
+
     # Create parser with version
     parser = create_parser(version=__version__)
 
@@ -167,6 +174,65 @@ def _initialize_project_registry():
         # Continue execution - registry failure shouldn't block startup
 
 
+def _verify_mcp_gateway_startup():
+    """
+    Verify MCP Gateway configuration on startup.
+
+    WHY: The MCP gateway should be automatically configured and verified on startup
+    to provide a seamless experience with diagnostic tools, file summarizer, and
+    ticket service.
+
+    DESIGN DECISION: This is non-blocking - failures are logged but don't prevent
+    startup to ensure claude-mpm remains functional even if MCP gateway has issues.
+    """
+    try:
+        import asyncio
+        from ..services.mcp_gateway.core.startup_verification import (
+            verify_mcp_gateway_on_startup,
+            is_mcp_gateway_configured,
+        )
+
+        # Quick check first - if already configured, skip detailed verification
+        if is_mcp_gateway_configured():
+            return
+
+        # Run detailed verification in background
+        # Note: We don't await this to avoid blocking startup
+        def run_verification():
+            try:
+                loop = asyncio.new_event_loop()
+                asyncio.set_event_loop(loop)
+                results = loop.run_until_complete(verify_mcp_gateway_on_startup())
+                loop.close()
+
+                # Log results but don't block
+                from ..core.logger import get_logger
+                logger = get_logger("cli")
+
+                if results.get("gateway_configured"):
+                    logger.debug("MCP Gateway verification completed successfully")
+                else:
+                    logger.debug("MCP Gateway verification completed with warnings")
+
+            except Exception as e:
+                from ..core.logger import get_logger
+                logger = get_logger("cli")
+                logger.debug(f"MCP Gateway verification failed: {e}")
+
+        # Run in background thread to avoid blocking startup
+        import threading
+        verification_thread = threading.Thread(target=run_verification, daemon=True)
+        verification_thread.start()
+
+    except Exception as e:
+        # Import logger here to avoid circular imports
+        from ..core.logger import get_logger
+
+        logger = get_logger("cli")
+        logger.debug(f"Failed to start MCP Gateway verification: {e}")
+        # Continue execution - MCP gateway issues shouldn't block startup
+
+
 def _ensure_run_attributes(args):
     """
     Ensure run command attributes exist when defaulting to run.
@@ -185,10 +251,28 @@ def _ensure_run_attributes(args):
     args.input = getattr(args, "input", None)
     args.non_interactive = getattr(args, "non_interactive", False)
     args.no_native_agents = getattr(args, "no_native_agents", False)
-    args.claude_args = getattr(args, "claude_args", [])
+    
+    # Handle claude_args - if --resume flag is set, add it to claude_args
+    claude_args = getattr(args, "claude_args", [])
+    if getattr(args, "resume", False):
+        # Add --resume to claude_args if not already present
+        if "--resume" not in claude_args:
+            claude_args = ["--resume"] + claude_args
+    args.claude_args = claude_args
+    
     args.launch_method = getattr(args, "launch_method", "exec")
     args.websocket = getattr(args, "websocket", False)
     args.websocket_port = getattr(args, "websocket_port", 8765)
+    # CRITICAL: Include mpm_resume attribute for session resumption
+    args.mpm_resume = getattr(args, "mpm_resume", None)
+    # Also include monitor and force attributes
+    args.monitor = getattr(args, "monitor", False)
+    args.force = getattr(args, "force", False)
+    # Include dependency checking attributes
+    args.check_dependencies = getattr(args, "check_dependencies", True)
+    args.force_check_dependencies = getattr(args, "force_check_dependencies", False)
+    args.no_prompt = getattr(args, "no_prompt", False)
+    args.force_prompt = getattr(args, "force_prompt", False)
 
 
 def _execute_command(command: str, args) -> int:
